#
# spec file for package xrandr
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xrandr
Version:        1.5.3
Release:        1.3
Summary:        Primitive command line interface to RandR extension
License:        MIT
Group:          System/X11/Utilities
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
# PATCH-FEATURE-UPSTREAM xrandr-print-outputs-per-provider.patch federico@suse.com - Make the --listproviders option also print which outputs are supported by each provider
Patch1:         xrandr-print-outputs-per-provider.patch
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto) >= 7.0.17
BuildRequires:  pkgconfig(xrandr) >= 1.3
BuildRequires:  pkgconfig(xrender)
# Currently required in order to make use of RANDR 1.4 enhancements
# which have been implemented by the following drivers: intel,
# radeon, nouveau, modesetting and nvidia
Supplements:    xorg-x11-server
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6

%description
Xrandr is used to set the size, orientation and/or reflection of
the outputs for a screen. It can also set the screen size.

%prep
%autosetup -p1

%build
%configure
%make_build

%install
%make_install
# do not ship xkeystone, see fdo#35984
rm %{buildroot}%{_bindir}/xkeystone

%files
%license COPYING
%doc ChangeLog README.md
%{_bindir}/xrandr
%{_mandir}/man1/xrandr.1%{?ext_man}

%changelog
* Thu Nov  7 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.5.3
  * set_gamma_info: remove unnecessary round-trip to server
  * Reworked transform fix from Arsalan Awan
  * xrandr: Print/consume the CTM prop in human readable form
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Sun Dec  4 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.5.2
  * gitlab CI: add a basic build test
  * Fix spelling/wording issues
  * gitlab CI: stop requiring Signed-off-by in commits
  * Variable scope reductions as suggested by cppcheck
  * Fix a -Wsign-compare warning
  * Remove unused macros left over from original RandR 1.2 code
  * Remove unused definition of rectangle_t
  * Constify array argument to find_last_non_clamped()
- refreshed xrandr-print-outputs-per-provider.patch
* Mon Mar 15 2021 Dirk Müller <dmueller@suse.com>
- modernize spec-file (move license to licensedir)
* Tue Aug 20 2019 Stefan Dirsch <sndirsch@suse.com>
- update to version 1.5.1
  * Update configure.ac bug URL for gitlab migration
  * autogen: add default patch prefix
  * autogen.sh: use exec instead of waiting for configure to finish init the name to 0
  * autogen.sh: use quoted string variables
  * xrandr: fix crash if some modes cannot be found
  * xrandr: document that we accept '--dpi output'
  * xrandr: suppress misleading indentation warning
  * xrandr: allow a single value for --scale
  * xrandr: stricter --scale argument parsing
  * xrandr.man: grammar tuning
  * xrandr: allow single value for --gamma
  * xrandr.man: document the monitor manipulation options
  * xrandr: gamma and scaling factors must be positive
  * xrandr: Add a "--filter" flag
  * xrandr: Fix deleting inactive monitors
  * man: Document the new --filter option
  * Document format of --dpi option in non-ambiguous way
  * Document that --dpi and --fbmm options set DPI of whole X screen
  * Update README for gitlab migration
- superseded U_xrandr_suppress-misleading-indentation-warning.patch,
  U_xrandr_add-filter-flag.patch
* Mon Nov 20 2017 zaitor@opensuse.org
- Add U_xrandr_suppress-misleading-indentation-warning.patch: When
  printing out rotations, we print a space before any item other
  than the first, and set `first = False` in each block where we
  print. However, this is done in the same line as the conditional
  that checks if first is set, which may give the impression that
  the assignment is also under the conditional. This is not the
  case, and recent GCC warns about this.
- Add U_xrandr_add-filter-flag.patch: Flag can be set to
  "nearest" or "bilinear".
* Mon May 29 2017 sndirsch@suse.com
- includes everything needed for missing sle issue entries:
  fate #320388 (bsc#1041382)
- Add xrandr-print-outputs-per-provider.patch from sle12. This makes
  the --listproviders option in xrandr(1) also print which outputs are
  supported by each provider or GPU. (patch by federico@suse.com)
* Thu Feb 25 2016 mimi.vx@gmail.com
- update to version 1.5.0
  This release adds support for the new monitor objects added in RandR 1.5, and
  fixes a few bugs.
* Wed Aug  6 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.4.3:
  This minor bugfix release fixes gamma ramp calculations on GPUs with unusual
  gamma table configurations, removes redundant "Setting reflection" messages
  when - --verbose is specified, adds the ability for the -x and -y switches
  to be used to undo previous reflections, and adds the missing --brightness
  option to the - --help usage summary.
* Sat Mar 29 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.4.2:
  This minor bugfix release restores the ability to disconnect
  providers from each other using "0x0" as the provider XID.  For
  example, to disconnect a display offload sink from its source,
  use: "xrandr --setprovideroutputsource <sink> 0x0"
  This release also formats the GUID provided by DisplayPort 1.2
  displays in traditional GUID form.
  Finally, this release increases the precision of refresh rate
  calculations to disambiguate modes with very similar refresh
  rates and to improve the accuracy for interlaced modes.
* Thu Oct 17 2013 sndirsch@suse.com
- install the package by default; currently xrandr is required in
  order to make use of RANDR 1.4 enhancements, which have been
  implemented by the following drivers: intel, radeon, nouveau,
  modesetting and nvidia
* Sun Jul 21 2013 zaitor@opensuse.org
- Update to version 1.4.1:
  + Combine usage message strings.
  + Declare capability_name() as returning const char *.
  + fdo#56923 - Make command line options consistent (single vs
    double dash).
  + Protect config.h like usual.
  + xrandr: calloc XRRModeInfo's passed to libXrandr.
  + Print spaces between XA_ATOM property values.
* Wed Feb 13 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.4.0:
- New features:
  + Support for RandR 1.4's provider objects.  See the --listproviders,
  - -setprovideroutputsource, and --setprovideroffloadsink options for more
    information.
  + --set now allows a comma-separated list of values.  This is useful with the
    Border property to configure different border adjustments for different edges
    of the screen.
  + --scale-from, which specifies a scaling transform based on the desired
    desktop size.
  + --query now indicates which output, if any, is primary.
  - Also contains a number of bug fixes.
  One notable behavior change is that the --gamma option now takes the actual
  gamma value rather than the reciprocal of the gamma value.  This matches the
  behavior of other programs such as xgamma and the gamma configuration options in
  xorg.conf.
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 1.3.5:
  + Correct several issues found by static code analysis tools.
  + Clean up some build configuration issues.
- Add pkgconfig(xproto) BuildRequires: new upstream dependency.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xrandr from xorg-x11. Initial version: 1.3.4.
